    { "gtk_sheet_get_type", _wrap_gtk_sheet_get_type, 1 },
    { "gtk_plot_data_get_type", _wrap_gtk_plot_data_get_type, 1 },
    { "gtk_plot_bar_get_type", _wrap_gtk_plot_bar_get_type, 1 },
    { "gtk_plot_box_get_type", _wrap_gtk_plot_box_get_type, 1 },
    { "gtk_plot_flux_get_type", _wrap_gtk_plot_flux_get_type, 1 },
    { "gtk_plot_surface_get_type", _wrap_gtk_plot_surface_get_type, 1 },
    { "gtk_plot_csurface_get_type", _wrap_gtk_plot_csurface_get_type, 1 },
    { "gtk_plot_pixmap_get_type", _wrap_gtk_plot_pixmap_get_type, 1 },
    { "gtk_plot_axis_get_type", _wrap_gtk_plot_axis_get_type, 1 },
    { "gtk_plot_get_type", _wrap_gtk_plot_get_type, 1 },
    { "gtk_plot_polar_get_type", _wrap_gtk_plot_polar_get_type, 1 },
    { "gtk_plot3d_get_type", _wrap_gtk_plot3d_get_type, 1 },
    { "gtk_plot_canvas_get_type", _wrap_gtk_plot_canvas_get_type, 1 },
    { "gtk_plot_canvas_get_pixmap", _wrap_gtk_plot_canvas_get_pixmap, 1 },
    { "gtk_icon_list_get_type", _wrap_gtk_icon_list_get_type, 1 },
    { "gtk_icon_list_get_num_icons", _wrap_gtk_icon_list_get_num_icons, 1 },
    { "gtk_dir_tree_get_type", _wrap_gtk_dir_tree_get_type, 1 },
    { "gtk_file_list_get_type", _wrap_gtk_file_list_get_type, 1 },
    { "gtk_icon_file_selection_get_type", _wrap_gtk_icon_file_selection_get_type, 1 },
    { "gtk_icon_file_selection_get_path_label", _wrap_gtk_icon_file_selection_get_path_label, 1 },
    { "gtk_icon_file_selection_get_dir_tree", _wrap_gtk_icon_file_selection_get_dir_tree, 1 },
    { "gtk_icon_file_selection_get_file_list", _wrap_gtk_icon_file_selection_get_file_list, 1 },
    { "gtk_icon_file_selection_get_history_combo", _wrap_gtk_icon_file_selection_get_history_combo, 1 },
    { "gtk_icon_file_selection_get_file_entry", _wrap_gtk_icon_file_selection_get_file_entry, 1 },
    { "gtk_icon_file_selection_get_filter_entry", _wrap_gtk_icon_file_selection_get_filter_entry, 1 },
    { "gtk_icon_file_selection_get_ok_button", _wrap_gtk_icon_file_selection_get_ok_button, 1 },
    { "gtk_icon_file_selection_get_cancel_button", _wrap_gtk_icon_file_selection_get_cancel_button, 1 },
    { "gtk_icon_file_selection_get_action_area", _wrap_gtk_icon_file_selection_get_action_area, 1 },
    { "gtk_item_entry_get_type", _wrap_gtk_item_entry_get_type, 1 },
    { "gtk_font_combo_get_type", _wrap_gtk_font_combo_get_type, 1 },
    { "gtk_font_combo_get_name_combo", _wrap_gtk_font_combo_get_name_combo, 1 },
    { "gtk_font_combo_get_size_combo", _wrap_gtk_font_combo_get_size_combo, 1 },
    { "gtk_font_combo_get_bold_button", _wrap_gtk_font_combo_get_bold_button, 1 },
    { "gtk_font_combo_get_italic_button", _wrap_gtk_font_combo_get_italic_button, 1 },
    { "gtk_font_combo_get_font", _wrap_gtk_font_combo_get_font, 1 },
    { "gtk_font_combo_get_height", _wrap_gtk_font_combo_get_height, 1 },
    { "gtk_font_combo_get_italic", _wrap_gtk_font_combo_get_italic, 1 },
    { "gtk_font_combo_get_bold", _wrap_gtk_font_combo_get_bold, 1 },
    { "gtk_combo_box_get_type", _wrap_gtk_combo_box_get_type, 1 },
    { "gtk_combo_box_get_button", _wrap_gtk_combo_box_get_button, 1 },
    { "gtk_combo_box_get_arrow", _wrap_gtk_combo_box_get_arrow, 1 },
    { "gtk_combo_box_get_popup", _wrap_gtk_combo_box_get_popup, 1 },
    { "gtk_combo_box_get_popwin", _wrap_gtk_combo_box_get_popwin, 1 },
    { "gtk_combo_box_get_frame", _wrap_gtk_combo_box_get_frame, 1 },
    { "gtk_border_combo_get_type", _wrap_gtk_border_combo_get_type, 1 },
    { "gtk_color_combo_get_type", _wrap_gtk_color_combo_get_type, 1 },
    { "gtk_toggle_combo_get_type", _wrap_gtk_toggle_combo_get_type, 1 },
    { "gtk_char_selection_get_type", _wrap_gtk_char_selection_get_type, 1 },
    { "gtk_char_selection_get_font_combo", _wrap_gtk_char_selection_get_font_combo, 1 },
    { "gtk_char_selection_get_ok_button", _wrap_gtk_char_selection_get_ok_button, 1 },
    { "gtk_char_selection_get_cancel_button", _wrap_gtk_char_selection_get_cancel_button, 1 },
    { "GTK_SHEET_SET_FLAGS", _wrap_GTK_SHEET_SET_FLAGS, 1 },
    { "GTK_SHEET_UNSET_FLAGS", _wrap_GTK_SHEET_UNSET_FLAGS, 1 },
    { "GTK_PLOT_CANVAS_SET_FLAGS", _wrap_GTK_PLOT_CANVAS_SET_FLAGS, 1 },
    { "GTK_PLOT_CANVAS_UNSET_FLAGS", _wrap_GTK_PLOT_CANVAS_UNSET_FLAGS, 1 },
    { "gtk_sheet_set_hadjustment", _wrap_gtk_sheet_set_hadjustment, 1 },
    { "gtk_sheet_set_vadjustment", _wrap_gtk_sheet_set_vadjustment, 1 },
    { "gtk_sheet_change_entry", _wrap_gtk_sheet_change_entry, 1 },
    { "gtk_sheet_get_entry", _wrap_gtk_sheet_get_entry, 1 },
    { "gtk_sheet_get_entry_widget", _wrap_gtk_sheet_get_entry_widget, 1 },
    { "gtk_sheet_get_state", _wrap_gtk_sheet_get_state, 1 },
    { "gtk_sheet_get_columns_count", _wrap_gtk_sheet_get_columns_count, 1 },
    { "gtk_sheet_get_rows_count", _wrap_gtk_sheet_get_rows_count, 1 },
    { "gtk_sheet_set_selection_mode", _wrap_gtk_sheet_set_selection_mode, 1 },
    { "gtk_sheet_set_title", _wrap_gtk_sheet_set_title, 1 },
    { "gtk_sheet_freeze", _wrap_gtk_sheet_freeze, 1 },
    { "gtk_sheet_thaw", _wrap_gtk_sheet_thaw, 1 },
    { "gtk_sheet_set_background", _wrap_gtk_sheet_set_background, 1 },
    { "gtk_sheet_set_grid", _wrap_gtk_sheet_set_grid, 1 },
    { "gtk_sheet_show_grid", _wrap_gtk_sheet_show_grid, 1 },
    { "gtk_sheet_grid_visible", _wrap_gtk_sheet_grid_visible, 1 },
    { "gtk_sheet_set_column_title", _wrap_gtk_sheet_set_column_title, 1 },
    { "gtk_sheet_set_row_title", _wrap_gtk_sheet_set_row_title, 1 },
    { "gtk_sheet_row_button_add_label", _wrap_gtk_sheet_row_button_add_label, 1 },
    { "gtk_sheet_column_button_add_label", _wrap_gtk_sheet_column_button_add_label, 1 },
    { "gtk_sheet_row_button_justify", _wrap_gtk_sheet_row_button_justify, 1 },
    { "gtk_sheet_column_button_justify", _wrap_gtk_sheet_column_button_justify, 1 },
    { "gtk_sheet_moveto", _wrap_gtk_sheet_moveto, 1 },
    { "gtk_sheet_set_row_titles_width", _wrap_gtk_sheet_set_row_titles_width, 1 },
    { "gtk_sheet_set_column_titles_height", _wrap_gtk_sheet_set_column_titles_height, 1 },
    { "gtk_sheet_show_column_titles", _wrap_gtk_sheet_show_column_titles, 1 },
    { "gtk_sheet_show_row_titles", _wrap_gtk_sheet_show_row_titles, 1 },
    { "gtk_sheet_hide_column_titles", _wrap_gtk_sheet_hide_column_titles, 1 },
    { "gtk_sheet_hide_row_titles", _wrap_gtk_sheet_hide_row_titles, 1 },
    { "gtk_sheet_column_set_sensitivity", _wrap_gtk_sheet_column_set_sensitivity, 1 },
    { "gtk_sheet_columns_set_sensitivity", _wrap_gtk_sheet_columns_set_sensitivity, 1 },
    { "gtk_sheet_row_set_sensitivity", _wrap_gtk_sheet_row_set_sensitivity, 1 },
    { "gtk_sheet_rows_set_sensitivity", _wrap_gtk_sheet_rows_set_sensitivity, 1 },
    { "gtk_sheet_column_set_visibility", _wrap_gtk_sheet_column_set_visibility, 1 },
    { "gtk_sheet_column_label_set_visibility", _wrap_gtk_sheet_column_label_set_visibility, 1 },
    { "gtk_sheet_columns_labels_set_visibility", _wrap_gtk_sheet_columns_labels_set_visibility, 1 },
    { "gtk_sheet_row_set_visibility", _wrap_gtk_sheet_row_set_visibility, 1 },
    { "gtk_sheet_row_label_set_visibility", _wrap_gtk_sheet_row_label_set_visibility, 1 },
    { "gtk_sheet_rows_labels_set_visibility", _wrap_gtk_sheet_rows_labels_set_visibility, 1 },
    { "gtk_sheet_select_row", _wrap_gtk_sheet_select_row, 1 },
    { "gtk_sheet_select_column", _wrap_gtk_sheet_select_column, 1 },
    { "gtk_sheet_unclip_range", _wrap_gtk_sheet_unclip_range, 1 },
    { "gtk_sheet_get_vadjustment", _wrap_gtk_sheet_get_vadjustment, 1 },
    { "gtk_sheet_get_hadjustment", _wrap_gtk_sheet_get_hadjustment, 1 },
    { "gtk_sheet_unselect_range", _wrap_gtk_sheet_unselect_range, 1 },
    { "gtk_sheet_set_active_cell", _wrap_gtk_sheet_set_active_cell, 1 },
    { "gtk_sheet_set_cell", _wrap_gtk_sheet_set_cell, 1 },
    { "gtk_sheet_set_cell_text", _wrap_gtk_sheet_set_cell_text, 1 },
    { "gtk_sheet_cell_clear", _wrap_gtk_sheet_cell_clear, 1 },
    { "gtk_sheet_cell_delete", _wrap_gtk_sheet_cell_delete, 1 },
    { "gtk_sheet_cell_get_state", _wrap_gtk_sheet_cell_get_state, 1 },
    { "gtk_sheet_set_column_width", _wrap_gtk_sheet_set_column_width, 1 },
    { "gtk_sheet_set_row_height", _wrap_gtk_sheet_set_row_height, 1 },
    { "gtk_sheet_add_column", _wrap_gtk_sheet_add_column, 1 },
    { "gtk_sheet_add_row", _wrap_gtk_sheet_add_row, 1 },
    { "gtk_sheet_insert_rows", _wrap_gtk_sheet_insert_rows, 1 },
    { "gtk_sheet_insert_columns", _wrap_gtk_sheet_insert_columns, 1 },
    { "gtk_sheet_delete_rows", _wrap_gtk_sheet_delete_rows, 1 },
    { "gtk_sheet_delete_columns", _wrap_gtk_sheet_delete_columns, 1 },
    { "gtk_sheet_column_set_justification", _wrap_gtk_sheet_column_set_justification, 1 },
    { "gtk_sheet_attach", _wrap_gtk_sheet_attach, 1 },
    { "gtk_sheet_move_child", _wrap_gtk_sheet_move_child, 1 },
    { "gtk_sheet_button_attach", _wrap_gtk_sheet_button_attach, 1 },
    { "gtk_plot_data_paint", _wrap_gtk_plot_data_paint, 1 },
    { "gtk_plot_data_update", _wrap_gtk_plot_data_update, 1 },
    { "gtk_plot_data_draw_points", _wrap_gtk_plot_data_draw_points, 1 },
    { "gtk_plot_data_draw_symbol", _wrap_gtk_plot_data_draw_symbol, 1 },
    { "gtk_plot_data_set_a_scale", _wrap_gtk_plot_data_set_a_scale, 1 },
    { "gtk_plot_data_get_a_scale", _wrap_gtk_plot_data_get_a_scale, 1 },
    { "gtk_plot_data_show_labels", _wrap_gtk_plot_data_show_labels, 1 },
    { "gtk_plot_data_labels_set_attributes", _wrap_gtk_plot_data_labels_set_attributes, 1 },
    { "gtk_plot_data_get_numpoints", _wrap_gtk_plot_data_get_numpoints, 1 },
    { "gtk_plot_data_set_connector", _wrap_gtk_plot_data_set_connector, 1 },
    { "gtk_plot_data_get_connector", _wrap_gtk_plot_data_get_connector, 1 },
    { "gtk_plot_data_set_line_attributes", _wrap_gtk_plot_data_set_line_attributes, 1 },
    { "gtk_plot_data_set_x_attributes", _wrap_gtk_plot_data_set_x_attributes, 1 },
    { "gtk_plot_data_set_y_attributes", _wrap_gtk_plot_data_set_y_attributes, 1 },
    { "gtk_plot_data_set_z_attributes", _wrap_gtk_plot_data_set_z_attributes, 1 },
    { "gtk_plot_data_show_xerrbars", _wrap_gtk_plot_data_show_xerrbars, 1 },
    { "gtk_plot_data_show_yerrbars", _wrap_gtk_plot_data_show_yerrbars, 1 },
    { "gtk_plot_data_show_zerrbars", _wrap_gtk_plot_data_show_zerrbars, 1 },
    { "gtk_plot_data_hide_xerrbars", _wrap_gtk_plot_data_hide_xerrbars, 1 },
    { "gtk_plot_data_hide_yerrbars", _wrap_gtk_plot_data_hide_yerrbars, 1 },
    { "gtk_plot_data_hide_zerrbars", _wrap_gtk_plot_data_hide_zerrbars, 1 },
    { "gtk_plot_data_fill_area", _wrap_gtk_plot_data_fill_area, 1 },
    { "gtk_plot_data_area_is_filled", _wrap_gtk_plot_data_area_is_filled, 1 },
    { "gtk_plot_data_show_legend", _wrap_gtk_plot_data_show_legend, 1 },
    { "gtk_plot_data_hide_legend", _wrap_gtk_plot_data_hide_legend, 1 },
    { "gtk_plot_data_set_legend", _wrap_gtk_plot_data_set_legend, 1 },
    { "gtk_plot_data_set_legend_precision", _wrap_gtk_plot_data_set_legend_precision, 1 },
    { "gtk_plot_data_get_legend_precision", _wrap_gtk_plot_data_get_legend_precision, 1 },
    { "gtk_plot_data_set_name", _wrap_gtk_plot_data_set_name, 1 },
    { "gtk_plot_data_set_gradient_mask", _wrap_gtk_plot_data_set_gradient_mask, 1 },
    { "gtk_plot_data_get_gradient_mask", _wrap_gtk_plot_data_get_gradient_mask, 1 },
    { "gtk_plot_data_gradient_set_visible", _wrap_gtk_plot_data_gradient_set_visible, 1 },
    { "gtk_plot_data_gradient_visible", _wrap_gtk_plot_data_gradient_visible, 1 },
    { "gtk_plot_data_draw_gradient", _wrap_gtk_plot_data_draw_gradient, 1 },
    { "gtk_plot_data_gradient_autoscale_a", _wrap_gtk_plot_data_gradient_autoscale_a, 1 },
    { "gtk_plot_data_gradient_autoscale_da", _wrap_gtk_plot_data_gradient_autoscale_da, 1 },
    { "gtk_plot_data_gradient_autoscale_z", _wrap_gtk_plot_data_gradient_autoscale_z, 1 },
    { "gtk_plot_data_set_gradient_colors", _wrap_gtk_plot_data_set_gradient_colors, 1 },
    { "gtk_plot_data_set_gradient", _wrap_gtk_plot_data_set_gradient, 1 },
    { "gtk_plot_data_remove_markers", _wrap_gtk_plot_data_remove_markers, 1 },
    { "gtk_plot_data_show_markers", _wrap_gtk_plot_data_show_markers, 1 },
    { "gtk_plot_data_markers_visible", _wrap_gtk_plot_data_markers_visible, 1 },
    { "gtk_plot_bar_set_width", _wrap_gtk_plot_bar_set_width, 1 },
    { "gtk_plot_bar_get_width", _wrap_gtk_plot_bar_get_width, 1 },
    { "gtk_plot_flux_set_arrow", _wrap_gtk_plot_flux_set_arrow, 1 },
    { "gtk_plot_surface_set_color", _wrap_gtk_plot_surface_set_color, 1 },
    { "gtk_plot_surface_set_shadow", _wrap_gtk_plot_surface_set_shadow, 1 },
    { "gtk_plot_surface_set_grid_foreground", _wrap_gtk_plot_surface_set_grid_foreground, 1 },
    { "gtk_plot_surface_set_grid_background", _wrap_gtk_plot_surface_set_grid_background, 1 },
    { "gtk_plot_surface_set_grid_visible", _wrap_gtk_plot_surface_set_grid_visible, 1 },
    { "gtk_plot_surface_get_grid_visible", _wrap_gtk_plot_surface_get_grid_visible, 1 },
    { "gtk_plot_surface_set_mesh_visible", _wrap_gtk_plot_surface_set_mesh_visible, 1 },
    { "gtk_plot_surface_get_mesh_visible", _wrap_gtk_plot_surface_get_mesh_visible, 1 },
    { "gtk_plot_surface_set_light", _wrap_gtk_plot_surface_set_light, 1 },
    { "gtk_plot_surface_set_ambient", _wrap_gtk_plot_surface_set_ambient, 1 },
    { "gtk_plot_surface_use_height_gradient", _wrap_gtk_plot_surface_use_height_gradient, 1 },
    { "gtk_plot_surface_set_transparent", _wrap_gtk_plot_surface_set_transparent, 1 },
    { "gtk_plot_surface_get_nx", _wrap_gtk_plot_surface_get_nx, 1 },
    { "gtk_plot_surface_get_ny", _wrap_gtk_plot_surface_get_ny, 1 },
    { "gtk_plot_surface_set_xstep", _wrap_gtk_plot_surface_set_xstep, 1 },
    { "gtk_plot_surface_set_ystep", _wrap_gtk_plot_surface_set_ystep, 1 },
    { "gtk_plot_surface_get_xstep", _wrap_gtk_plot_surface_get_xstep, 1 },
    { "gtk_plot_surface_get_ystep", _wrap_gtk_plot_surface_get_ystep, 1 },
    { "gtk_plot_surface_build_mesh", _wrap_gtk_plot_surface_build_mesh, 1 },
    { "gtk_plot_surface_recalc_nodes", _wrap_gtk_plot_surface_recalc_nodes, 1 },
    { "gtk_plot_csurface_set_lines_visible", _wrap_gtk_plot_csurface_set_lines_visible, 1 },
    { "gtk_plot_csurface_get_lines_visible", _wrap_gtk_plot_csurface_get_lines_visible, 1 },
    { "gtk_plot_csurface_set_lines_only", _wrap_gtk_plot_csurface_set_lines_only, 1 },
    { "gtk_plot_csurface_lines_only", _wrap_gtk_plot_csurface_lines_only, 1 },
    { "gtk_plot_csurface_set_labels_visible", _wrap_gtk_plot_csurface_set_labels_visible, 1 },
    { "gtk_plot_csurface_labels_visible", _wrap_gtk_plot_csurface_labels_visible, 1 },
    { "gtk_plot_pixmap_get_pixmap", _wrap_gtk_plot_pixmap_get_pixmap, 1 },
    { "gtk_plot_pixmap_get_mask", _wrap_gtk_plot_pixmap_get_mask, 1 },
    { "gtk_plot_set_drawable", _wrap_gtk_plot_set_drawable, 1 },
    { "gtk_plot_get_drawable", _wrap_gtk_plot_get_drawable, 1 },
    { "gtk_plot_set_background_pixmap", _wrap_gtk_plot_set_background_pixmap, 1 },
    { "gtk_plot_set_transparent", _wrap_gtk_plot_set_transparent, 1 },
    { "gtk_plot_is_transparent", _wrap_gtk_plot_is_transparent, 1 },
    { "gtk_plot_set_background", _wrap_gtk_plot_set_background, 1 },
    { "gtk_plot_paint", _wrap_gtk_plot_paint, 1 },
    { "gtk_plot_move", _wrap_gtk_plot_move, 1 },
    { "gtk_plot_resize", _wrap_gtk_plot_resize, 1 },
    { "gtk_plot_set_magnification", _wrap_gtk_plot_set_magnification, 1 },
    { "gtk_plot_move_resize", _wrap_gtk_plot_move_resize, 1 },
    { "gtk_plot_clip_data", _wrap_gtk_plot_clip_data, 1 },
    { "gtk_plot_set_xrange", _wrap_gtk_plot_set_xrange, 1 },
    { "gtk_plot_set_yrange", _wrap_gtk_plot_set_yrange, 1 },
    { "gtk_plot_set_range", _wrap_gtk_plot_set_range, 1 },
    { "gtk_plot_autoscale", _wrap_gtk_plot_autoscale, 1 },
    { "gtk_plot_set_xscale", _wrap_gtk_plot_set_xscale, 1 },
    { "gtk_plot_set_yscale", _wrap_gtk_plot_set_yscale, 1 },
    { "gtk_plot_get_xscale", _wrap_gtk_plot_get_xscale, 1 },
    { "gtk_plot_get_yscale", _wrap_gtk_plot_get_yscale, 1 },
    { "gtk_plot_get_axis", _wrap_gtk_plot_get_axis, 1 },
    { "gtk_plot_axis_set_visible", _wrap_gtk_plot_axis_set_visible, 1 },
    { "gtk_plot_axis_visible", _wrap_gtk_plot_axis_visible, 1 },
    { "gtk_plot_axis_set_title", _wrap_gtk_plot_axis_set_title, 1 },
    { "gtk_plot_axis_show_title", _wrap_gtk_plot_axis_show_title, 1 },
    { "gtk_plot_axis_hide_title", _wrap_gtk_plot_axis_hide_title, 1 },
    { "gtk_plot_axis_move_title", _wrap_gtk_plot_axis_move_title, 1 },
    { "gtk_plot_axis_justify_title", _wrap_gtk_plot_axis_justify_title, 1 },
    { "gtk_plot_axis_set_attributes", _wrap_gtk_plot_axis_set_attributes, 1 },
    { "gtk_plot_axis_set_ticks", _wrap_gtk_plot_axis_set_ticks, 1 },
    { "gtk_plot_axis_set_major_ticks", _wrap_gtk_plot_axis_set_major_ticks, 1 },
    { "gtk_plot_axis_set_minor_ticks", _wrap_gtk_plot_axis_set_minor_ticks, 1 },
    { "gtk_plot_axis_set_ticks_length", _wrap_gtk_plot_axis_set_ticks_length, 1 },
    { "gtk_plot_axis_set_ticks_width", _wrap_gtk_plot_axis_set_ticks_width, 1 },
    { "gtk_plot_axis_show_ticks", _wrap_gtk_plot_axis_show_ticks, 1 },
    { "gtk_plot_axis_set_ticks_limits", _wrap_gtk_plot_axis_set_ticks_limits, 1 },
    { "gtk_plot_axis_unset_ticks_limits", _wrap_gtk_plot_axis_unset_ticks_limits, 1 },
    { "gtk_plot_axis_show_labels", _wrap_gtk_plot_axis_show_labels, 1 },
    { "gtk_plot_axis_title_set_attributes", _wrap_gtk_plot_axis_title_set_attributes, 1 },
    { "gtk_plot_axis_set_labels_attributes", _wrap_gtk_plot_axis_set_labels_attributes, 1 },
    { "gtk_plot_axis_set_labels_numbers", _wrap_gtk_plot_axis_set_labels_numbers, 1 },
    { "gtk_plot_axis_set_labels_offset", _wrap_gtk_plot_axis_set_labels_offset, 1 },
    { "gtk_plot_axis_get_labels_offset", _wrap_gtk_plot_axis_get_labels_offset, 1 },
    { "gtk_plot_axis_use_custom_tick_labels", _wrap_gtk_plot_axis_use_custom_tick_labels, 1 },
    { "gtk_plot_axis_set_labels_suffix", _wrap_gtk_plot_axis_set_labels_suffix, 1 },
    { "gtk_plot_axis_set_labels_prefix", _wrap_gtk_plot_axis_set_labels_prefix, 1 },
    { "gtk_plot_axis_get_labels_suffix", _wrap_gtk_plot_axis_get_labels_suffix, 1 },
    { "gtk_plot_axis_get_labels_prefix", _wrap_gtk_plot_axis_get_labels_prefix, 1 },
    { "gtk_plot_x0_set_visible", _wrap_gtk_plot_x0_set_visible, 1 },
    { "gtk_plot_x0_visible", _wrap_gtk_plot_x0_visible, 1 },
    { "gtk_plot_y0_set_visible", _wrap_gtk_plot_y0_set_visible, 1 },
    { "gtk_plot_y0_visible", _wrap_gtk_plot_y0_visible, 1 },
    { "gtk_plot_grids_set_on_top", _wrap_gtk_plot_grids_set_on_top, 1 },
    { "gtk_plot_grids_on_top", _wrap_gtk_plot_grids_on_top, 1 },
    { "gtk_plot_grids_set_visible", _wrap_gtk_plot_grids_set_visible, 1 },
    { "gtk_plot_y0line_set_attributes", _wrap_gtk_plot_y0line_set_attributes, 1 },
    { "gtk_plot_x0line_set_attributes", _wrap_gtk_plot_x0line_set_attributes, 1 },
    { "gtk_plot_major_vgrid_set_attributes", _wrap_gtk_plot_major_vgrid_set_attributes, 1 },
    { "gtk_plot_minor_vgrid_set_attributes", _wrap_gtk_plot_minor_vgrid_set_attributes, 1 },
    { "gtk_plot_major_hgrid_set_attributes", _wrap_gtk_plot_major_hgrid_set_attributes, 1 },
    { "gtk_plot_minor_hgrid_set_attributes", _wrap_gtk_plot_minor_hgrid_set_attributes, 1 },
    { "gtk_plot_show_legends", _wrap_gtk_plot_show_legends, 1 },
    { "gtk_plot_hide_legends", _wrap_gtk_plot_hide_legends, 1 },
    { "gtk_plot_set_legends_border", _wrap_gtk_plot_set_legends_border, 1 },
    { "gtk_plot_legends_move", _wrap_gtk_plot_legends_move, 1 },
    { "gtk_plot_legends_set_attributes", _wrap_gtk_plot_legends_set_attributes, 1 },
    { "gtk_plot_polar_rotate", _wrap_gtk_plot_polar_rotate, 1 },
    { "gtk_plot3d_autoscale", _wrap_gtk_plot3d_autoscale, 1 },
    { "gtk_plot3d_rotate", _wrap_gtk_plot3d_rotate, 1 },
    { "gtk_plot3d_reset_angles", _wrap_gtk_plot3d_reset_angles, 1 },
    { "gtk_plot3d_rotate_x", _wrap_gtk_plot3d_rotate_x, 1 },
    { "gtk_plot3d_rotate_y", _wrap_gtk_plot3d_rotate_y, 1 },
    { "gtk_plot3d_rotate_z", _wrap_gtk_plot3d_rotate_z, 1 },
    { "gtk_plot3d_set_xrange", _wrap_gtk_plot3d_set_xrange, 1 },
    { "gtk_plot3d_set_yrange", _wrap_gtk_plot3d_set_yrange, 1 },
    { "gtk_plot3d_set_zrange", _wrap_gtk_plot3d_set_zrange, 1 },
    { "gtk_plot3d_set_xfactor", _wrap_gtk_plot3d_set_xfactor, 1 },
    { "gtk_plot3d_set_yfactor", _wrap_gtk_plot3d_set_yfactor, 1 },
    { "gtk_plot3d_set_zfactor", _wrap_gtk_plot3d_set_zfactor, 1 },
    { "gtk_plot3d_get_xfactor", _wrap_gtk_plot3d_get_xfactor, 1 },
    { "gtk_plot3d_get_yfactor", _wrap_gtk_plot3d_get_yfactor, 1 },
    { "gtk_plot3d_get_zfactor", _wrap_gtk_plot3d_get_zfactor, 1 },
    { "gtk_plot3d_plane_set_color", _wrap_gtk_plot3d_plane_set_color, 1 },
    { "gtk_plot3d_plane_set_visible", _wrap_gtk_plot3d_plane_set_visible, 1 },
    { "gtk_plot3d_plane_visible", _wrap_gtk_plot3d_plane_visible, 1 },
    { "gtk_plot3d_corner_set_visible", _wrap_gtk_plot3d_corner_set_visible, 1 },
    { "gtk_plot3d_corner_visible", _wrap_gtk_plot3d_corner_visible, 1 },
    { "gtk_plot3d_corner_set_attributes", _wrap_gtk_plot3d_corner_set_attributes, 1 },
    { "gtk_plot3d_frame_set_attributes", _wrap_gtk_plot3d_frame_set_attributes, 1 },
    { "gtk_plot3d_get_axis", _wrap_gtk_plot3d_get_axis, 1 },
    { "gtk_plot3d_get_side", _wrap_gtk_plot3d_get_side, 1 },
    { "gtk_plot3d_axis_show_major_ticks", _wrap_gtk_plot3d_axis_show_major_ticks, 1 },
    { "gtk_plot3d_axis_show_minor_ticks", _wrap_gtk_plot3d_axis_show_minor_ticks, 1 },
    { "gtk_plot3d_axis_show_labels", _wrap_gtk_plot3d_axis_show_labels, 1 },
    { "gtk_plot3d_axis_show_title", _wrap_gtk_plot3d_axis_show_title, 1 },
    { "gtk_plot3d_axis_hide_title", _wrap_gtk_plot3d_axis_hide_title, 1 },
    { "gtk_plot3d_axis_set_ticks", _wrap_gtk_plot3d_axis_set_ticks, 1 },
    { "gtk_plot3d_axis_set_major_ticks", _wrap_gtk_plot3d_axis_set_major_ticks, 1 },
    { "gtk_plot3d_axis_set_minor_ticks", _wrap_gtk_plot3d_axis_set_minor_ticks, 1 },
    { "gtk_plot3d_axis_set_ticks_length", _wrap_gtk_plot3d_axis_set_ticks_length, 1 },
    { "gtk_plot3d_axis_set_ticks_width", _wrap_gtk_plot3d_axis_set_ticks_width, 1 },
    { "gtk_plot3d_axis_show_ticks", _wrap_gtk_plot3d_axis_show_ticks, 1 },
    { "gtk_plot3d_set_titles_offset", _wrap_gtk_plot3d_set_titles_offset, 1 },
    { "gtk_plot3d_get_titles_offset", _wrap_gtk_plot3d_get_titles_offset, 1 },
    { "gtk_plot3d_major_grids_set_visible", _wrap_gtk_plot3d_major_grids_set_visible, 1 },
    { "gtk_plot3d_minor_grids_set_visible", _wrap_gtk_plot3d_minor_grids_set_visible, 1 },
    { "gtk_plot3d_major_zgrid_set_attributes", _wrap_gtk_plot3d_major_zgrid_set_attributes, 1 },
    { "gtk_plot3d_minor_zgrid_set_attributes", _wrap_gtk_plot3d_minor_zgrid_set_attributes, 1 },
    { "gtk_plot_canvas_new", _wrap_gtk_plot_canvas_new, 1 },
    { "gtk_plot_canvas_paint", _wrap_gtk_plot_canvas_paint, 1 },
    { "gtk_plot_canvas_refresh", _wrap_gtk_plot_canvas_refresh, 1 },
    { "gtk_plot_canvas_freeze", _wrap_gtk_plot_canvas_freeze, 1 },
    { "gtk_plot_canvas_thaw", _wrap_gtk_plot_canvas_thaw, 1 },
    { "gtk_plot_canvas_grid_set_visible", _wrap_gtk_plot_canvas_grid_set_visible, 1 },
    { "gtk_plot_canvas_grid_set_step", _wrap_gtk_plot_canvas_grid_set_step, 1 },
    { "gtk_plot_canvas_grid_set_attributes", _wrap_gtk_plot_canvas_grid_set_attributes, 1 },
    { "gtk_plot_canvas_add_plot", _wrap_gtk_plot_canvas_add_plot, 1 },
    { "gtk_plot_canvas_set_active_plot", _wrap_gtk_plot_canvas_set_active_plot, 1 },
    { "gtk_plot_canvas_cancel_action", _wrap_gtk_plot_canvas_cancel_action, 1 },
    { "gtk_plot_canvas_unselect", _wrap_gtk_plot_canvas_unselect, 1 },
    { "gtk_plot_canvas_get_active_plot", _wrap_gtk_plot_canvas_get_active_plot, 1 },
    { "gtk_plot_canvas_get_active_data", _wrap_gtk_plot_canvas_get_active_data, 1 },
    { "gtk_plot_canvas_set_size", _wrap_gtk_plot_canvas_set_size, 1 },
    { "gtk_plot_canvas_set_magnification", _wrap_gtk_plot_canvas_set_magnification, 1 },
    { "gtk_plot_canvas_set_background", _wrap_gtk_plot_canvas_set_background, 1 },
    { "gtk_icon_list_set_mode", _wrap_gtk_icon_list_set_mode, 1 },
    { "gtk_icon_list_get_mode", _wrap_gtk_icon_list_get_mode, 1 },
    { "gtk_icon_list_set_editable", _wrap_gtk_icon_list_set_editable, 1 },
    { "gtk_icon_list_is_editable", _wrap_gtk_icon_list_is_editable, 1 },
    { "gtk_icon_list_set_row_spacing", _wrap_gtk_icon_list_set_row_spacing, 1 },
    { "gtk_icon_list_get_row_spacing", _wrap_gtk_icon_list_get_row_spacing, 1 },
    { "gtk_icon_list_set_col_spacing", _wrap_gtk_icon_list_set_col_spacing, 1 },
    { "gtk_icon_list_get_col_spacing", _wrap_gtk_icon_list_get_col_spacing, 1 },
    { "gtk_icon_list_set_text_space", _wrap_gtk_icon_list_set_text_space, 1 },
    { "gtk_icon_list_get_text_space", _wrap_gtk_icon_list_get_text_space, 1 },
    { "gtk_icon_list_set_icon_border", _wrap_gtk_icon_list_set_icon_border, 1 },
    { "gtk_icon_list_get_icon_border", _wrap_gtk_icon_list_get_icon_border, 1 },
    { "gtk_icon_list_set_icon_width", _wrap_gtk_icon_list_set_icon_width, 1 },
    { "gtk_icon_list_get_icon_width", _wrap_gtk_icon_list_get_icon_width, 1 },
    { "gtk_icon_list_freeze", _wrap_gtk_icon_list_freeze, 1 },
    { "gtk_icon_list_thaw", _wrap_gtk_icon_list_thaw, 1 },
    { "gtk_icon_list_set_background", _wrap_gtk_icon_list_set_background, 1 },
    { "gtk_icon_list_update", _wrap_gtk_icon_list_update, 1 },
    { "gtk_icon_list_set_selection_mode", _wrap_gtk_icon_list_set_selection_mode, 1 },
    { "gtk_icon_list_unselect_all", _wrap_gtk_icon_list_unselect_all, 1 },
    { "gtk_dir_tree_new", _wrap_gtk_dir_tree_new, 1 },
    { "gtk_dir_tree_open_dir", _wrap_gtk_dir_tree_open_dir, 1 },
    { "gtk_file_list_set_filter", _wrap_gtk_file_list_set_filter, 1 },
    { "gtk_file_list_open_dir", _wrap_gtk_file_list_open_dir, 1 },
    { "gtk_file_list_get_path", _wrap_gtk_file_list_get_path, 1 },
    { "gtk_file_list_get_filetype", _wrap_gtk_file_list_get_filetype, 1 },
    { "gtk_file_list_add_type_filter", _wrap_gtk_file_list_add_type_filter, 1 },
    { "gtk_icon_file_selection_open_dir", _wrap_gtk_icon_file_selection_open_dir, 1 },
    { "gtk_icon_file_selection_show_hidden", _wrap_gtk_icon_file_selection_show_hidden, 1 },
    { "gtk_icon_file_selection_show_tree", _wrap_gtk_icon_file_selection_show_tree, 1 },
    { "gtk_icon_file_selection_set_filter", _wrap_gtk_icon_file_selection_set_filter, 1 },
    { "gtk_item_entry_new", _wrap_gtk_item_entry_new, 1 },
    { "gtk_item_entry_new_with_max_length", _wrap_gtk_item_entry_new_with_max_length, 1 },
    { "gtk_item_entry_set_text", _wrap_gtk_item_entry_set_text, 1 },
    { "gtk_item_entry_set_justification", _wrap_gtk_item_entry_set_justification, 1 },
    { "gtk_font_combo_new", _wrap_gtk_font_combo_new, 1 },
    { "gtk_font_combo_select", _wrap_gtk_font_combo_select, 1 },
    { "gtk_font_combo_select_nth", _wrap_gtk_font_combo_select_nth, 1 },
    { "gtk_combo_box_new", _wrap_gtk_combo_box_new, 1 },
    { "gtk_combo_box_hide_popdown_window", _wrap_gtk_combo_box_hide_popdown_window, 1 },
    { "gtk_border_combo_new", _wrap_gtk_border_combo_new, 1 },
    { "gtk_color_combo_get_color_at", _wrap_gtk_color_combo_get_color_at, 1 },
    { "gtk_toggle_combo_new", _wrap_gtk_toggle_combo_new, 1 },
    { "gtk_toggle_combo_get_nrows", _wrap_gtk_toggle_combo_get_nrows, 1 },
    { "gtk_toggle_combo_get_ncols", _wrap_gtk_toggle_combo_get_ncols, 1 },
    { "gtk_toggle_combo_select", _wrap_gtk_toggle_combo_select, 1 },
    { "gtk_char_selection_new", _wrap_gtk_char_selection_new, 1 },
    { "gtk_char_selection_set_selection", _wrap_gtk_char_selection_set_selection, 1 },
    { "gtk_char_selection_get_selection", _wrap_gtk_char_selection_get_selection, 1 },
    { "gtk_psfont_init", _wrap_gtk_psfont_init, 1 },
    { "gtk_psfont_unref", _wrap_gtk_psfont_unref, 1 },
    { "gtk_psfont_get_psfontname", _wrap_gtk_psfont_get_psfontname, 1 },
